Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(356)

Unified Diff: remoting/host/setup/me2me_native_messaging_host.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/setup/me2me_native_messaging_host.cc
diff --git a/remoting/host/setup/me2me_native_messaging_host.cc b/remoting/host/setup/me2me_native_messaging_host.cc
index 018f28c645cc54b0c870dd09563231169d64d8b1..89cd2072357c726eadaf0698c1b7f94858568d7e 100644
--- a/remoting/host/setup/me2me_native_messaging_host.cc
+++ b/remoting/host/setup/me2me_native_messaging_host.cc
@@ -53,7 +53,7 @@ const char* kSupportedFeatures[] = {
};
// Helper to extract the "config" part of a message as a DictionaryValue.
// Returns NULL on failure, and logs an error message.
scoped_ptr<base::DictionaryValue> ConfigDictionaryFromMessage(
scoped_ptr<base::DictionaryValue> message) {
scoped_ptr<base::DictionaryValue> result;
@@ -505,7 +505,7 @@ void Me2MeNativeMessagingHost::SendCredentialsResponse(
}
void Me2MeNativeMessagingHost::OnError() {
// Trigger a host shutdown by sending a NULL message.
channel_->SendMessage(nullptr);
}
@@ -544,7 +544,7 @@ bool Me2MeNativeMessagingHost::DelegateToElevatedHost(
if (elevated_channel_)
elevated_channel_->SendMessage(message.Pass());
- return elevated_channel_ != NULL;
+ return elevated_channel_ != nullptr;
}
void Me2MeNativeMessagingHost::EnsureElevatedHostCreated() {
@@ -667,7 +667,7 @@ void Me2MeNativeMessagingHost::EnsureElevatedHostCreated() {
return;
}
- if (!::ConnectNamedPipe(delegate_write_handle.Get(), NULL)) {
+ if (!::ConnectNamedPipe(delegate_write_handle.Get(), nullptr)) {
DWORD error = ::GetLastError();
if (error != ERROR_PIPE_CONNECTED) {
PLOG(ERROR) << "Unable to connect '" << input_pipe_name << "'";
@@ -676,7 +676,7 @@ void Me2MeNativeMessagingHost::EnsureElevatedHostCreated() {
}
}
- if (!::ConnectNamedPipe(delegate_read_handle.Get(), NULL)) {
+ if (!::ConnectNamedPipe(delegate_read_handle.Get(), nullptr)) {
DWORD error = ::GetLastError();
if (error != ERROR_PIPE_CONNECTED) {
PLOG(ERROR) << "Unable to connect '" << output_pipe_name << "'";
@@ -53,7 +53,7 @@ const char* kSupportedFeatures[] = {
};
// Helper to extract the "config" part of a message as a DictionaryValue.
-// Returns NULL on failure, and logs an error message.
+// Returns nullptr on failure, and logs an error message.
scoped_ptr<base::DictionaryValue> ConfigDictionaryFromMessage(
scoped_ptr<base::DictionaryValue> message) {
@@ -505,7 +505,7 @@ void Me2MeNativeMessagingHost::SendCredentialsResponse(
}
void Me2MeNativeMessagingHost::OnError() {
- // Trigger a host shutdown by sending a NULL message.
+ // Trigger a host shutdown by sending a nullptr message.
channel_->SendMessage(nullptr);
}
« no previous file with comments | « remoting/host/setup/daemon_installer_win.cc ('k') | remoting/host/setup/me2me_native_messaging_host_main.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698